# Input files for Quantum ESPRESSO and EPW

This directory contains all relevant input files for the first-principles
calculations.

## Changes in EPW

In order to properly implement the phonon self-energy in Eq. (12) of the
manuscript, we used a slightly modified version of the EPW code. The second,
static term contains a fraction of occupation and energy differences. In the
case where both the numerator and the denominator vanish, as per L'Hôpital's
rule, the fraction has to be replaced by the derivative of the Fermi function.
The relevant code is found in the subroutine `spectral_func_ph_q` in the file
`EPW/src/spectral_func.f90` (QE 7.3 or below):

    fact = wgkq - wgkk
    etmp1 = ekq - ekk
    weight = wkf(ikk) * fact * REAL(cone / (etmp1 + ci * degaussw))

Here, we substitute the last line by the following code:

    IF (etmp1 == 0) THEN
        weight = -wkf(ikk) * 0.5 * inv_eptemp / (1 + COSH(ekk * inv_eptemp))
    ELSE
        weight = wkf(ikk) * fact / etmp1
    ENDIF

Moreover, we prefer to use the analytical expressions for the real and the
imaginary parts of complex numbers. Directly below the above code we find:

    DO iw = 1, nw_specfun
       ...
       weight = wkf(ikk) * fact * REAL(cone / (etmp2 + ci * degaussw))
       ...
       weight = pi * wkf(ikk) * fact * w0gauss(etmp2 * inv_degaussw, 0) * inv_degaussw
       ...
    ENDDO

We replace this by:

    DO iw = 1, nw_specfun
       ...
       weight = wkf(ikk) * fact * etmp2 / (etmp2 ** 2 + degaussw ** 2)
       ...
       weight = -wkf(ikk) * fact * degaussw / (etmp2 ** 2 + degaussw ** 2)
       ...
    ENDDO
